@@ -4,7 +4,7 @@ from decimal import Decimal
 import pandas as pd
 
 from powerbot_backtesting.utils import _order_matching
-from powerbot_backtesting.utils.constants import *
+from powerbot_backtesting.utils.constants import TIME_HM, DATE_YMD_TIME_HMS_TZ, DATE_YMD_TIME_HMS
 
 
 def flexpos_algo(orderbooks: dict[str, pd.DataFrame],
@@ -40,7 +40,7 @@ def flexpos_algo(orderbooks: dict[str, pd.DataFrame],
 
     # Checking Parameters
     if not all(len(i) == len([*orderbooks]) for i in [marg_prices, buy_sell_spread, init_prod, min_prod, max_prod]):
-        raise Exception(f"All parameters have to be same length as amount of contracts in orderbook!")
+        raise Exception("All parameters have to be same length as amount of contracts in orderbook!")
 
     # Executing Flex Algo
     results_flex = flex_algo(orderbooks, marg_prices, buy_sell_spread, init_prod, min_prod, max_prod, closing_from)
@@ -189,8 +189,7 @@ def pc_algo(orderbooks: dict[str, pd.DataFrame],
         buy_price = marg_prices[nr][0]
         sell_price = marg_prices[nr][1]
         contract_time = key.split(" ")
-        contract_time = int((datetime.strptime(contract_time[3], TIME_HM) - datetime.strptime(contract_time[1],
-                                                                                              TIME_HM)).seconds / 60)
+        contract_time = int((datetime.strptime(contract_time[3], TIME_HM) - datetime.strptime(contract_time[1], TIME_HM)).seconds / 60)
 
         if isinstance(contract, pd.DataFrame) and contract.empty or not contract:
             results[key]["Remaining_quant"] = "No data"
